@@ -89,7 +89,7 @@ if ($do==1) {
             }
          }
       }
-      my $packs='';
+      my $packs='';$|=1;
       foreach my $pack (sort keys %need_packages) {
          $packs.="$pack ";
       }
@@ -110,38 +110,45 @@ if ($do==1) {
       # https://technet.microsoft.com/en-us/library/hh831475.aspx
       # http://twiki.org/cgi-bin/view/TWiki/TWikiOnWindowsIISCygwin
       # https://www.iis.net/configreference/system.webserver/fastcgi
-      ($stdout,$stderr)=$handle->cmd("DISM.EXE /enable-feature /all ".
-         "/online /featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
+      #($stdout,$stderr)=$handle->cmd("DISM.EXE /enable-feature /all ".
+      #   "/online /featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
+      #   "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
+      #   "/featureName:IIS-DefaultDocument /featureName:IIS-DirectoryBrowsing ".
+      #   "/featureName:IIS-HttpErrors /featureName:IIS-HttpRedirect ".
+      #   "/featureName:IIS-ApplicationDevelopment /featureName:IIS-ASPNET ".
+      #   "/featureName:IIS-NetFxExtensibility /featureName:IIS-ASPNET45 ".
+      #   "/featureName:IIS-NetFxExtensibility45 /featureName:IIS-ASP ".
+      #   "/featureName:IIS-CGI /featureName:IIS-ISAPIExtensions ".
+      #   "/featureName:IIS-ISAPIFilter /featureName:IIS-ServerSideIncludes ".
+      #   "/featureName:IIS-HealthAndDiagnostics /featureName:IIS-HttpLogging ".
+      #   "/featureName:IIS-LoggingLibraries /featureName:IIS-RequestMonitor ".
+      #   "/featureName:IIS-HttpTracing /featureName:IIS-CustomLogging ".
+      #   "/featureName:IIS-ODBCLogging /featureName:IIS-Security ".
+      #   "/featureName:IIS-BasicAuthentication ".
+      #   "/featureName:IIS-WindowsAuthentication ".
+      #   "/featureName:IIS-DigestAuthentication ".
+      #   "/featureName:IIS-ClientCertificateMappingAuthentication ".
+      #   "/featureName:IIS-IISCertificateMappingAuthentication ".
+      #   "/featureName:IIS-URLAuthorization /featureName:IIS-RequestFiltering ".
+      #   "/featureName:IIS-IPSecurity /featureName:IIS-Performance ".
+      #   "/featureName:IIS-HttpCompressionStatic ".
+      #   "/featureName:IIS-HttpCompressionDynamic /featureName:IIS-WebDAV ".
+      #   "/featureName:IIS-WebServerManagementTools ".
+      #   "/featureName:IIS-ManagementScriptingTools ".
+      #   "/featureName:IIS-ManagementService ".
+      #   "/featureName:IIS-IIS6ManagementCompatibility ".
+      #   "/featureName:IIS-Metabase /featureName:IIS-WMICompatibility ".
+      #   "/featureName:IIS-LegacyScripts /featureName:NetFx4Extended-ASPNET45 ".
+      #   "/featureName:IIS-ApplicationInit /featureName:IIS-WebSockets ".
+      #   "/featureName:IIS-CertProvider /featureName:IIS-ManagementConsole ".
+      #   "/featureName:IIS-LegacySnapIn",'__display__');
+      ($stdout,$stderr)=$handle->cmd("DISM.EXE /online /enable-feature ".
+         "/featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
          "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
          "/featureName:IIS-DefaultDocument /featureName:IIS-DirectoryBrowsing ".
          "/featureName:IIS-HttpErrors /featureName:IIS-HttpRedirect ".
-         "/featureName:IIS-ApplicationDevelopment /featureName:IIS-ASPNET ".
-         "/featureName:IIS-NetFxExtensibility /featureName:IIS-ASPNET45 ".
-         "/featureName:IIS-NetFxExtensibility45 /featureName:IIS-ASP ".
-         "/featureName:IIS-CGI /featureName:IIS-ISAPIExtensions ".
-         "/featureName:IIS-ISAPIFilter /featureName:IIS-ServerSideIncludes ".
-         "/featureName:IIS-HealthAndDiagnostics /featureName:IIS-HttpLogging ".
-         "/featureName:IIS-LoggingLibraries /featureName:IIS-RequestMonitor ".
-         "/featureName:IIS-HttpTracing /featureName:IIS-CustomLogging ".
-         "/featureName:IIS-ODBCLogging /featureName:IIS-Security ".
-         "/featureName:IIS-BasicAuthentication ".
-         "/featureName:IIS-WindowsAuthentication ".
-         "/featureName:IIS-DigestAuthentication ".
-         "/featureName:IIS-ClientCertificateMappingAuthentication ".
-         "/featureName:IIS-IISCertificateMappingAuthentication ".
-         "/featureName:IIS-URLAuthorization /featureName:IIS-RequestFiltering ".
-         "/featureName:IIS-IPSecurity /featureName:IIS-Performance ".
-         "/featureName:IIS-HttpCompressionStatic ".
-         "/featureName:IIS-HttpCompressionDynamic /featureName:IIS-WebDAV ".
-         "/featureName:IIS-WebServerManagementTools ".
-         "/featureName:IIS-ManagementScriptingTools ".
-         "/featureName:IIS-ManagementService ".
-         "/featureName:IIS-IIS6ManagementCompatibility ".
-         "/featureName:IIS-Metabase /featureName:IIS-WMICompatibility ".
-         "/featureName:IIS-LegacyScripts /featureName:NetFx4Extended-ASPNET45 ".
-         "/featureName:IIS-ApplicationInit /featureName:IIS-WebSockets ".
-         "/featureName:IIS-CertProvider /featureName:IIS-ManagementConsole ".
-         "/featureName:IIS-LegacySnapIn",'__display__');
+         "/featureName:IIS-CGI /featureName:IIS-ManagementConsole",
+         '__display__');
       my $appcmd="$ENV{WINDIR}/SYSTEM32/inetsrv";
       ($appcmd,$stderr)=$handle->cmd("cygpath -u $appcmd");
       my $cyglocb=$handle->cmd("cygpath -w /");
@@ -154,13 +161,15 @@ if ($do==1) {
       my $sleep=0;
       while (1==1) {
         my $ls_output=$handle->cmd("ls -1");
-        last if -1<index $ls_output,'appcmd.exe';
+        last if -1<index $ls_output,'config/applicationHost.config';
         sleep 2;
         last if $sleep++>300;
       }
+      sleep 2;
       ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
          "/id:2 /physicalPath:$cyglocwf\\root /bindings:http/*:4000",
          '__display__');
+      sleep 2;
       ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
          "system.webServer/fastCgi /+[\"fullpath=\'$cyglocb\\script\\".
          "CGI_script.bat\',arguments=\'$cyglocwf\\script\\".
@@ -168,6 +177,7 @@ if ($do==1) {
          "idleTimeout=\'300\',activityTimeout=\'30\',requestTimeout='\90\',".
          "instanceMaxRequests=\'1000\',protocol=\'NamedPipe\',".
          "flushNamedPipe=\'False\']\" /commit:apphost",'__display__');
+      sleep 2;
       ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
          "system.webServer/handlers /+\"[name=\'FullAutoAPI\',".
          "path=\'*\',verb=\'GET,HEAD,POST\',modules=".
@@ -175,16 +185,9 @@ if ($do==1) {
          "CGI_Script.bat|$cyglocwf\\script\\fullautoapi_fastcgi.pl -e\',".
          "resourceType=\'Unspecified\',requireAccess=\'Script\']\" ".
          "/commit:apphost",'__display__');
-      ($stdout,$stderr)=$handle->cmd("./appcmd set config -section:".
-         "system.serviceModel/serviceHostingEnvironment ".
-         "/+\"[multipleSiteBindingsEnabled=\'true\']\" ".
-         "/commit:apphost",'__display__');
       ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("touch CGI_Script.bat",'__display__');
       $cyglocb=~s/\\/\\x5C/g;
-      my $content=<<END;
-$cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
-END
       ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
       ($stdout,$stderr)=$handle->cwd("FullAutoAPI/script");
       ($stdout,$stderr)=$handle->cmd("touch CGI_Script");
@@ -195,12 +198,12 @@ END
       #          search and replace - and paste back results.
       #          use copy/paste or cat file and copy/paste results.):
       #
-      #          !  -   \\x21
-      #          "  -   \\x22
+      #          !  -   \\x21     %  -  \\x25
+      #          "  -   \\x22     \  -  \\x5C
       #          $  -   \\x24
       #
       my $content=<<END;
-$cyglocb\\bin\\bash -lc \\x22/bin/perl -e \\\\x22\\x241\\\\x24\\x24
+$cyglocb\\x5Cbin\\x5Cbash -lc \\x22/bin/perl \\x251 \\x252\\x22
 END
       ($stdout,$stderr)=$handle->cmd("echo -e \"$content\" > CGI_Script.bat");
       ($stdout,$stderr)=$handle->cwd("~");
